# vinfo
This repository shows how to build a pypi library. 
This is a simle example of vinfo for video or image file information.

# How to run vinfo

$ vinfo videofile

$ vinfo imagefile

# How to install vinfo

$ pip install vinfo


